#
# spec file for package python-sphinx_rtd_theme
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-sphinx_rtd_theme%{psuffix}
Version:        3.0.2
Release:        2.1
Summary:        ReadTheDocs.org theme for Sphinx
License:        Apache-2.0 AND MIT AND OFL-1.1
URL:            https://github.com/snide/sphinx_rtd_theme/
Source:         https://files.pythonhosted.org/packages/source/s/sphinx_rtd_theme/sphinx_rtd_theme-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Sphinx >= 1.6
Requires:       python-docutils
Requires:       python-sphinxcontrib-jquery >= 4.0
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module readthedocs-sphinx-ext}
BuildRequires:  %{python_module sphinxcontrib-jquery >= 4.0}
%endif
%python_subpackages

%description
This is a prototype mobile-friendly sphinx theme I made for readthedocs.org. It's
currently in development and includes some rtd variable checks that can be ignored
if you're just trying to use it on your project outside of that site.

%prep
%setup -q -n sphinx_rtd_theme-%{version}
dos2unix OFL-License.txt

# We cannot build the Javascript from source at this time, due to many missing
# dependencies.  Convince the build script to skip building the Javascript and
# go on to the python.
mkdir -p build/lib/%{srcname}/static/js
cp -p sphinx_rtd_theme/static/js/badge_only.js build/lib/%{srcname}/static/js
cp -p sphinx_rtd_theme/static/js/theme.js build/lib/%{srcname}/static/js
sed -i "/'build_py'/d" setup.py

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# https://github.com/readthedocs/sphinx_rtd_theme/issues/1558
%pytest -k "not test_basic"
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE OFL-License.txt Apache-License-2.0.txt
%doc README.rst
%{python_sitelib}/sphinx_rtd_theme
%{python_sitelib}/sphinx_rtd_theme-%{version}.dist-info
%endif

%changelog
* Mon Jun 16 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyroject macros.
* Sat Nov 23 2024 Dirk Müller <dmueller@suse.com>
- update to 3.0.2:
  * Attached flyout: show the current translation
  * Allow disabling selectors
  * Use black color for switcher options
  * Trigger search modal on "Search docs" input focus
  * Theme option flyout to enable/disable theme's flyout
  * Remove html5shiv
  * Adjust the expected test_basic output to match Sphinx 7.3+
* Tue Jul  2 2024 Dirk Müller <dmueller@suse.com>
- skip test_basic as it no longer works with sphinx 7.3
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.0:
  * Fix #1522: fix 'str' object has no attribute 'attributes'
  * Increment for next potential release
  * Fix AttributeError when one of css_files is a string
  * Add support for docutils==0.20.x
  * Use css_tag helper to inject CSS files
* Tue Aug 29 2023 Matej Cepl <mcepl@suse.com>
- Clean up the SPEC file
* Mon Aug 28 2023 Markéta Machová <mmachova@suse.com>
- Update to 1.3.0
  * Load jQuery correctly when using latest sphinxcontrib-jquery release
  * Relaxed requirements to include Sphinx release 7.0
* Fri May  5 2023 Dirk Müller <dmueller@suse.com>
- move jquery to runtime requires
* Fri May  5 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add missing BuildRequires on sphinxcontrib-jquery.
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.0:
  * python 3.11 support
  * translation updates
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.1.1
  * Docs: Add upgrade instructions and simplify conf.py (#1365)
  * Update versioning docs to be explicit about our versioning workflow (#1373)
- Update to 1.1.0 release (#1372)
  * Do not overflow object cross references (#1369)
  * Remove Jinja2 dependency (#1360)
  * Move context logic for layout.html to jinja (#1356)
  * Additions to Tox and Circle CI matrix (#1349)
  * Translation updates: Pull translations from transifex, push new sources (#1354)
  * Update layout.html to support a sphinx version that is not three-integers (#1345)
  * Add sphinx 5.2 to test matrix (#1348)
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.0:
  * compatibility with docutils 0.17
  * sphinx 4.1+ support
- drop sphinx41.patch: upstream
* Tue Jul 13 2021 Markéta Machová <mmachova@suse.com>
- Add sphinx41.patch to fix build with Sphinx 4.1.0
* Tue Apr 20 2021 Matthias Fehring <buschmann23@opensuse.org>
- remove python-docutils from Requires
* Mon Apr 19 2021 Matthias Fehring <buschmann23@opensuse.org>
- update to 0.5.2
  * depend on docutils < 0.17 (gh#readthedocs/sphinx_rtd_theme#1113)
* Tue Mar  2 2021 Dirk Müller <dmueller@suse.com>
- update to 0.5.1
  * no upstream changelog available
* Thu Jun  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to mulitbuild to avoid buildcycle
* Fri May 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.3:
  * Fixes for new Sphinx
- Enable tests
* Sat Aug 11 2018 arun@gmx.de
- specfile:
  * require Sphinx
- update to version 0.4.1:
  * Fixes
    + Line height adjustments for Liberation Mono (#656)
  * Other Changes
    + Add Sphinx as a dependency
* Mon Jul  2 2018 arun@gmx.de
- specfile:
  * be more specific in %%files:
    %%{python_sitelib}/* -> %%{python_sitelib}/sphinx_rtd_theme*
  * remove python-devel
- update to version 0.4.0:
  * Fixes
    + Do not rely on readthedocs.org for CSS/JS (#614)
    + Color accessibility improvements on the left navigation
  * Other Changes
    + Write theme version and build date at top of JavaScript and CSS
    + Changed code and literals to use a native font stack (#612)
    + Fix small styling issues
* Sun May  6 2018 arun@gmx.de
- update to version 0.3.1:
  * Revert part of #576 causing display issues with version selector
    menu
  * Backwards compatibility fixes for pre-0.3.0 releases (#623)
  * Fix mkdocs version selector (#622)
  * Add open list spacing (#591)
  * Fix table centering (#599)
* Tue Apr 24 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.3.0:
  * New Features
    + Add html language attribute
    + Allow setting 'rel' and 'title' attributes for stylesheets
    (#551)
    + Add option to style external links
    + Add github, gitlab, bitbucket page arguments option
    + Add pygments support
    + Add setuptools entry point allowing to use sphinx_rtd_theme as
    Sphinx html_theme directly.
    + Add language to the JS output variable
  * Fixes
    + Fix some HTML warnings and errors
    + Fix many styling issues
    + Fix many sidebar glitches
    + Fix line number spacing to align with the code lines
    + Hide Edit links on auto created pages
    + Include missing font files with the theme
  * Other Changes
    + Significant improvement of our documentation
    + Compress our Javascript files
    + Updated dependencies
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 0.2.4
  * Yet another patch to deal with extra builders outside Spinx, such as the
    singlehtml builders from the Read the Docs Sphinx extension
- Update to 0.2.3
  * Temporarily patch Sphinx issue with ``singlehtml`` builder by inspecting the
    builder in template.
- Update to 0.2.2
  * Roll back toctree fix in 0.2.1 (#367). This didn't fix the issue and
    introduced another bug with toctrees display.
- Update to 0.2.1
  * Add the ``rel`` HTML attribute to the footer links which point to
    the previous and next pages.
  * Fix toctree issue caused by Sphinx singlehtml builder (#367)
- Update to 0.2.0
  * Adds the ``comments`` block after the ``body`` block in the template
  * Added "Edit on GitLab" support
  * Many bug fixes
- Update to 0.1.10-alpha
  * Removes Sphinx dependency
  * Fixes hamburger on mobile display
  * Adds a ``body_begin`` block to the template
  * Add ``prev_next_buttons_location`` which can take the value ``bottom``,
    ``top``, ``both`` , ``None`` and will display the "Next" and "Previous"
    buttons accordingly
- Update to 0.1.9
  * Intermittent scrollbar visibility bug fixed. This change introduces a
    backwards incompatible change to the theme's layout HTML. This should only be
    a problem for derivative themes that have overridden styling of nav elements
    using direct decendant selectors. See `#215`_ for more information.
  * Safari overscroll bug fixed
  * Version added to the nav header
  * Revision id was added to the documentation footer if you are using RTD
  * An extra block, ``extrafooter`` was added to allow extra content in the
    document footer block
  * Fixed modernizr URL
  * Small display style changes on code blocks, figure captions, and nav elements
* Wed Apr 12 2017 toddrme2178@gmail.com
- Fix python_module macro definition.
* Mon Dec 19 2016 jmatejek@suse.com
- update for multipython build
* Mon Jul 18 2016 dmueller@suse.com
- update license
* Mon Jul 18 2016 tbechtold@suse.com
- Use pypi.io for Source url
* Wed May 13 2015 benoit.monin@gmx.fr
- update to version 0.1.8:
  * Start keeping changelog :)
  * Add support for Sphinx 1.3
  * Add sidebar headers for :caption: in Sphinx toctree
  * Clean up sidebar scrolling behavior so it never scrolls
    out of view
* Tue Jun 10 2014 prusnak@opensuse.org
- created package (version 0.1.6)
